==> igloo_0_1_4.tar.tgz: igloo_0_1_4/igloo/language/1/barnraiser_01/arrays/arr_acs.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of Igloo
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------
// Tom Calthrop - 14th September 2004 (info@barnraiser.org)




// ROLES ------------------------------------------------------------
/*
* group roles are used as defaults when setting up a group
* once set up group roles are stored in the database
* refer to the acs_config file to see how roles are attached to sections
*/
$lang['arr_acs']['role'][0] = 			"visitor";
$lang['arr_acs']['role'][1] = 			"administrator";
$lang['arr_acs']['role'][2] = 			"contributor";
$lang['arr_acs']['role'][3] = 			"member";



// RESOURCES ------------------------------------------------------------
$lang['arr_acs']['resource'][1] = 			"Administration";
$lang['arr_acs']['resource'][2] = 			"Network";
$lang['arr_acs']['resource'][3] = 			"Publishing";
$lang['arr_acs']['resource'][4] = 			"Shoutbox";
$lang['arr_acs']['resource'][5] = 			"Wiki";
$lang['arr_acs']['resource'][6] = 			"Discussions";
$lang['arr_acs']['resource'][7] = 			"Files";
$lang['arr_acs']['resource'][8] = 			"Schedule";
$lang['arr_acs']['resource'][9] = 			"Polls";
$lang['arr_acs']['resource'][10] = 			"Blog";
$lang['arr_acs']['resource'][11] = 			"Channels";
$lang['arr_acs']['resource'][12] = 			"Tag Management";


$lang['arr_acs']['resource_desc'][1] = 		"Here you can allow or deny administration section access.";
$lang['arr_acs']['resource_desc'][2] = 		"Here you can allow or deny access to the membership directory and network area and options. Members can tag other people - those tags are private.";
$lang['arr_acs']['resource_desc'][3] = 		"Here you can allow or deny member publishing options. They can publish to their network, the node (registered users) or to the public (everyone).";
$lang['arr_acs']['resource_desc'][4] = 		"Here you can allow or deny access to the shoutbox.";
$lang['arr_acs']['resource_desc'][5] = 		"Here you can allow or deny access to the wiki. There is one wiki for the node. If you give someone the rights to edit they can edit all pages.";
$lang['arr_acs']['resource_desc'][6] = 		"Here you can allow or deny access to the discussions area. They can add or edit Topics. When you add a topic you assign permissions to the discussion then.";
$lang['arr_acs']['resource_desc'][7] = 		"Here you can allow or deny access to the files. Files are not published. To publish them they are included in a blog or wiki (for example) and then they adopt the publishing rights of that parent item.";
$lang['arr_acs']['resource_desc'][8] = 		"Here you can allow or deny access to schedule items.";
$lang['arr_acs']['resource_desc'][9] = 		"Here you can allow or deny access to polls.";
$lang['arr_acs']['resource_desc'][10] = 	"Here you can allow or deny access to blogs.";
$lang['arr_acs']['resource_desc'][11] = 	"Here you can allow or deny access to channels.";
$lang['arr_acs']['resource_desc'][12] = 	"Here you can allow or deny access to tag management.";


// PRIVILEGES ------------------------------------------------------------
$lang['arr_acs']['privilege'][1] = 		"Allow access to membership administration area";
$lang['arr_acs']['privilege'][2] = 		"Allow composing and sending of newsletters";
$lang['arr_acs']['privilege'][3] = 		"Allow access to permissions area (ACS)";
$lang['arr_acs']['privilege'][4] = 		"Allow access to publishing area (RSP)";
$lang['arr_acs']['privilege'][5] = 		"Allow access to abuse report area";
$lang['arr_acs']['privilege'][6] = 		"Allow access to membership directory";
$lang['arr_acs']['privilege'][7] = 		"Allow access to network";
$lang['arr_acs']['privilege'][8] = 		"Allow internal invite to network";
$lang['arr_acs']['privilege'][9] = 		"Allow external invite to network";
$lang['arr_acs']['privilege'][10] = 	"Allow access";
$lang['arr_acs']['privilege'][11] = 	"Allow add/edit";
$lang['arr_acs']['privilege'][12] = 	"Allow commenting";
$lang['arr_acs']['privilege'][13] = 	"Allow locking";
$lang['arr_acs']['privilege'][14] = 	"Allow hidden";
$lang['arr_acs']['privilege'][15] = 	"Allow network publishing";
$lang['arr_acs']['privilege'][16] = 	"Allow node publishing";
$lang['arr_acs']['privilege'][17] = 	"Allow public publishing";
$lang['arr_acs']['privilege'][18] = 	"Allow tagging";
$lang['arr_acs']['privilege'][19] = 	"Allow access to view a persons profile";
$lang['arr_acs']['privilege'][20] = 	"Allow access to edit discussion topics";
$lang['arr_acs']['privilege'][21] = 	"Allow access to manage schedule recommended tag options";
$lang['arr_acs']['privilege'][22] = 	"Allow access to set the default page (the first page).";


?>

==> igloo_0_1_7.tar.tgz: igloo_0_1_7/igloo/language/1/barnraiser_01/arrays/arr_acs.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of Igloo
//
// Copyright (C) 2003, 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------
// Tom Calthrop - 14th September 2004 (info@barnraiser.org)




// ROLES ------------------------------------------------------------
/*
* group roles are used as defaults when setting up a group
* once set up group roles are stored in the database
* refer to the acs_config file to see how roles are attached to sections
*/
$lang['arr_acs']['role'][1] = 			"maintainer";
$lang['arr_acs']['role'][2] = 			"contributor";
$lang['arr_acs']['role'][3] = 			"member";
$lang['arr_acs']['role'][4] = 			"visitor"; // default



// RESOURCES ------------------------------------------------------------
$lang['arr_acs']['resource'][1] = 			"Administration";
$lang['arr_acs']['resource'][2] = 			"Network";
$lang['arr_acs']['resource'][3] = 			"Publishing";
$lang['arr_acs']['resource'][4] = 			"Shoutbox";
$lang['arr_acs']['resource'][5] = 			"Wiki";
$lang['arr_acs']['resource'][6] = 			"Discussions";
$lang['arr_acs']['resource'][7] = 			"Files";
$lang['arr_acs']['resource'][8] = 			"Schedule";
$lang['arr_acs']['resource'][9] = 			"Polls";
$lang['arr_acs']['resource'][10] = 			"Blog";
$lang['arr_acs']['resource'][11] = 			"Channels";
$lang['arr_acs']['resource'][12] = 			"Tag Management";


$lang['arr_acs']['resource_desc'][1] = 		"Here you can allow or deny administration section access.";
$lang['arr_acs']['resource_desc'][2] = 		"Here you can allow or deny access to the membership directory and network area and options. Members can tag other people - those tags are private.";
$lang['arr_acs']['resource_desc'][3] = 		"Here you can allow or deny member publishing options. They can publish to their network, the node (registered users) or to the public (everyone).";
$lang['arr_acs']['resource_desc'][4] = 		"Here you can allow or deny access to the shoutbox.";
$lang['arr_acs']['resource_desc'][5] = 		"Here you can allow or deny access to the wiki. There is one wiki for the node. If you give someone the rights to edit they can edit all pages.";
$lang['arr_acs']['resource_desc'][6] = 		"Here you can allow or deny access to the discussions area. They can add or edit Topics. When you add a topic you assign permissions to the discussion then.";
$lang['arr_acs']['resource_desc'][7] = 		"Here you can allow or deny access to the files. Files are not published. To publish them they are included in a blog or wiki (for example) and then they adopt the publishing rights of that parent item.";
$lang['arr_acs']['resource_desc'][8] = 		"Here you can allow or deny access to schedule items.";
$lang['arr_acs']['resource_desc'][9] = 		"Here you can allow or deny access to polls.";
$lang['arr_acs']['resource_desc'][10] = 	"Here you can allow or deny access to blogs.";
$lang['arr_acs']['resource_desc'][11] = 	"Here you can allow or deny access to channels.";
$lang['arr_acs']['resource_desc'][12] = 	"Here you can allow or deny access to tag management.";


// PRIVILEGES ------------------------------------------------------------
$lang['arr_acs']['privilege'][1] = 		"Allow access to membership administration area";
$lang['arr_acs']['privilege'][2] = 		"Allow composing and sending of newsletters";
$lang['arr_acs']['privilege'][3] = 		"Allow access to permissions area (ACS)";
$lang['arr_acs']['privilege'][4] = 		"Allow access to publishing area (RSP)";
$lang['arr_acs']['privilege'][5] = 		"Allow access to abuse report area";
$lang['arr_acs']['privilege'][6] = 		"Allow access to membership directory";
$lang['arr_acs']['privilege'][7] = 		"Allow access to network";
$lang['arr_acs']['privilege'][8] = 		"Allow internal invite to network";
$lang['arr_acs']['privilege'][9] = 		"Allow external invite to network";
$lang['arr_acs']['privilege'][10] = 	"Allow access";
$lang['arr_acs']['privilege'][11] = 	"Allow add/edit";
$lang['arr_acs']['privilege'][12] = 	"Allow commenting";
$lang['arr_acs']['privilege'][13] = 	"Allow locking";
$lang['arr_acs']['privilege'][14] = 	"Allow hidden";
$lang['arr_acs']['privilege'][15] = 	"Allow network publishing";
$lang['arr_acs']['privilege'][16] = 	"Allow group publishing";
$lang['arr_acs']['privilege'][17] = 	"Allow public publishing";
$lang['arr_acs']['privilege'][18] = 	"Allow tagging";
$lang['arr_acs']['privilege'][19] = 	"Allow access to view a persons profile";
$lang['arr_acs']['privilege'][20] = 	"Allow access to edit discussion topics";
$lang['arr_acs']['privilege'][21] = 	"Allow access to manage schedule recommended tag options";
$lang['arr_acs']['privilege'][22] = 	"Allow access to set the default page (the first page).";
$lang['arr_acs']['privilege'][23] = 	"Allow group featured page publishing.";
$lang['arr_acs']['privilege'][24] = 	"Allow public featured page publishing.";


?>
